//
//  PickerAPITesterAppDelegate.m
//  PickerAPITester
//
//  Created by Karl von Randow on 28/08/11.
//  Copyright 2011 XK72 Ltd. All rights reserved.
//

#import "TesterAppDelegate.h"

#import "TesterViewController.h"

static NSString *TesterAppDelegateVisitLink = @"Visit Link";

@implementation TesterAppDelegate

#pragma mark - Camera+ picker URL handling

- (BOOL)application:(UIApplication *)application handleOpenURL:(NSURL *)url {
    /* Note that your application has been in the background and may have been terminated.
     * The only CameraPlusIntegrationManager state that is restored is the pickerMode, which is
     * restored to indicate the mode used to pick images.
     */
    
    /* Handle the callback and notify the delegate. */
    if ([[CameraPlusIntegrationManager sharedManager] handleCameraPlusIntegrationCallback:url delegate:self]) {
        return YES;
    } else {
        /* Your own URL handling here, if any */
        return NO;
    }
}

#pragma mark - CameraPlusIntegrationManagerDelegate

- (void)cameraPlusIntegrationManager:(CameraPlusIntegrationManager *)manager 
                    didReceiveImages:(CameraPlusImages *)images
                            withMode:(CameraPlusIntegrationMode)mode {
    /* Handle the image or images received from Camera+. You will always have at least one image.
     * If you indicated that you don't support multiple images when you launched Camera+ you will 
     * only get one image back, otherwise the user may have chosen multiple.
     *
     * The images array will contain either UIImage objects or NSData objects depending upon your
     * setting of returnImagesAsData prior to invoking handleCameraPlusIntegrationCallback (see above).
     * The default is UIImage objects.
     *
     * The metadata array matches the images array and contains dictionaries of the metadata from
     * the camera for each image. If no metadata is availale there will be an empty dictionary.
     *
     * The pickerMode property on CameraPlusIntegrationManager will have been restored to the appropriate
     * value to indicate the mode that was used to pick the images.
     */
    
    /* In this example we take the images and show them in the view controller */
    UIImageView *imageView = self.viewController.imageView;
    if (images.numberOfImages == 1) {
        [imageView stopAnimating];
        imageView.image = [images imageAtIndex:0];
        
        NSLog(@"Metadata received: %@", [images metadataAtIndex:0]);
    } else if (images.numberOfImages > 1) {
        imageView.animationImages = [images images];
        imageView.animationDuration = 1;
        [imageView startAnimating];
        
        for (int i = 0; i < images.numberOfImages; i++) {
            NSLog(@"Metadata received: %@", [images metadataAtIndex:i]);
        }
    }
}

- (void)cameraPlusIntegrationManagerDidCancel:(CameraPlusIntegrationManager *)manager withMode:(CameraPlusIntegrationMode)mode {
    /* Handle a Cancel action from Camera+ */
}

- (void)cameraPlusIntegrationManagerDidShare:(CameraPlusIntegrationManager *)manager {
    UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Photo Shared"
                                                    message:@"The photo has been shared."
                                                   delegate:nil cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
    [alert show];
    [alert release];
}

- (void)cameraPlusIntegrationManager:(CameraPlusIntegrationManager *)manager didCreateWebLink:(NSURL *)link {
    [currentLink release];
    currentLink = [link retain];
    
    UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Photo Shared"
                                                    message:[NSString stringWithFormat:@"The photo has been shared at %@", link]
                                                   delegate:nil 
                                          cancelButtonTitle:@"Dismiss"
                                          otherButtonTitles:@"Visit Link", nil];
    alert.delegate = self;
    [alert show];
    [alert release];
}

#pragma mark - UIAlertViewDelegate

- (void)alertView:(UIAlertView *)alertView didDismissWithButtonIndex:(NSInteger)buttonIndex {
    NSString *buttonTitle = [alertView buttonTitleAtIndex:buttonIndex];
    
    if ([TesterAppDelegateVisitLink isEqualToString:buttonTitle]) {
        [[UIApplication sharedApplication] openURL:currentLink];
    }
}


#pragma mark - UIApplicationDelegate boilerplate

@synthesize window = _window;
@synthesize viewController = _viewController;

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {
    self.window.rootViewController = self.viewController;
    [self.window makeKeyAndVisible];
    
    return YES;
}

- (void)dealloc {
    [_window release];
    [_viewController release];
    [currentLink release];
    [super dealloc];
}

@end
