//
//  PickerAPITesterViewController.m
//  PickerAPITester
//
//  Created by Karl von Randow on 28/08/11.
//  Copyright 2011 XK72 Ltd. All rights reserved.
//

#import "TesterViewController.h"

#import <CameraPlusIntegrationAPI/CameraPlusIntegrationManager.h>

static NSString *TesterViewControllerTakePhoto = @"Take Photo";
static NSString *TesterViewControllerChooseExisting = @"Choose Existing";
static NSString *TesterViewControllerUseCameraPlus = @"Use Camera+";
static NSString *TesterViewControllerEditPhoto = @"Edit Photo";
static NSString *TesterViewControllerSharePhoto = @"Share Photo";
static NSString *TesterViewControllerCreateWebLink = @"Create Web Link";
static NSString *TesterViewControllerAppStore = @"App Store";
static NSString *TesterViewControllerUpdate = @"Update";
static NSString *TesterViewControllerRemovePhoto = @"Remove Photo";

@implementation TesterViewController

@synthesize imageView;

#pragma mark - Actions

- (IBAction)choosePhoto:(id)sender {
    /* First we check if Camera+ is installed, and if the correct version is installed */
    
    if (![CameraPlusIntegrationManager sharedManager].cameraPlusAvailable) {
        /* Camera+ not installed. You should either inform the user or simply don't display the option to use Camera+
         * at all.
         */
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Camera+ Required" 
                                                        message:@"This app requires Camera+ to be installed. Please download it from the App Store." 
                                                       delegate:self
                                              cancelButtonTitle:@"Cancel"
                                              otherButtonTitles:TesterViewControllerAppStore, nil];
        alert.delegate = self;
        [alert show];
        [alert release];
    } else if (![CameraPlusIntegrationManager sharedManager].cameraPlusIntegrationAvailable) {
        /* The Camera+ app integration API isn't available, but Camera+ is. This means that the installed 
         * version of Camera+ is too old. Ask the user to update to a newer version of Camera+.
         */
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Camera+ Update Required" 
                                                        message:@"This app requires a newer version of Camera+ than you have installed. Please update to the latest version from the App Store."
                                                       delegate:self
                                              cancelButtonTitle:@"Cancel"
                                              otherButtonTitles:TesterViewControllerUpdate, nil];
        [alert show];
        [alert release];
    } else {
        /* Camera+ is installed and available to use. */
        UIActionSheet *sheet;
        
        if (imageView.animationImages) {
            /* Multiple images currently in the imageView. Offer Sharing options. */
            sheet = [[UIActionSheet alloc] initWithTitle:nil
                                                delegate:self
                                       cancelButtonTitle:@"Cancel"
                                  destructiveButtonTitle:TesterViewControllerRemovePhoto
                                       otherButtonTitles:TesterViewControllerSharePhoto, TesterViewControllerCreateWebLink, nil];
        } else if (imageView.image) {
            /* Single image currently in the imageView. Offer Edit and Sharing options. */
            sheet = [[UIActionSheet alloc] initWithTitle:nil
                                                delegate:self
                                       cancelButtonTitle:@"Cancel"
                                  destructiveButtonTitle:TesterViewControllerRemovePhoto
                                       otherButtonTitles:TesterViewControllerEditPhoto, TesterViewControllerSharePhoto, TesterViewControllerCreateWebLink, nil];
        } else {
            /* No image currently in the imageImage. Offer picker options. */
            sheet = [[UIActionSheet alloc] initWithTitle:nil
                                                delegate:self
                                       cancelButtonTitle:nil
                                  destructiveButtonTitle:nil
                                       otherButtonTitles:nil];
            if ([UIImagePickerController isSourceTypeAvailable:UIImagePickerControllerSourceTypeCamera]) {
                [sheet addButtonWithTitle:TesterViewControllerTakePhoto];
            }
            if ([UIImagePickerController isSourceTypeAvailable:UIImagePickerControllerSourceTypePhotoLibrary]) {
                [sheet addButtonWithTitle:TesterViewControllerChooseExisting];
            }
            [sheet addButtonWithTitle:TesterViewControllerUseCameraPlus];
            sheet.cancelButtonIndex = [sheet addButtonWithTitle:@"Cancel"];
        }
        
        [sheet showInView:self.view];
    }
}

#pragma mark - UIActionSheetDelegate

- (void)actionSheet:(UIActionSheet *)actionSheet clickedButtonAtIndex:(NSInteger)buttonIndex {
    if (buttonIndex == actionSheet.cancelButtonIndex)
        return;
    
    /* Obtain the CameraPlusIntegrationManager */
    CameraPlusIntegrationManager *integrationManager = [CameraPlusIntegrationManager sharedManager];
    
    /* Configure the URL scheme to re-launch your application. This url scheme
     * must be configured in your Info.plist.
     */
    integrationManager.callbackURLScheme = @"com.taptaptap.CameraPlusIntegrationAPITester";
    
    /* Choose the size of images to return */
    integrationManager.imageSize = 1000;
    
    /* For sharing, whether to auto close the confirm message in Camera+ */
    integrationManager.autoCloseShareSuccess = NO;
    
    /* Launch Camera+ in the appropriate mode */
    NSString *buttonTitle = [actionSheet buttonTitleAtIndex:buttonIndex];
    if ([TesterViewControllerTakePhoto isEqual:buttonTitle]) {
        /* Take photo mode - this uses the standard UIImagePickerController */
        UIImagePickerController *imagePicker = [[UIImagePickerController alloc] init];
        imagePicker.sourceType = UIImagePickerControllerSourceTypeCamera;
        imagePicker.delegate = self;
        [self presentViewController:imagePicker animated:YES completion:NULL];
        [imagePicker release];
    } else if ([TesterViewControllerChooseExisting isEqual:buttonTitle]) {
        /* Choose existing mode - this uses the standard UIImagePickerController */
        UIImagePickerController *imagePicker = [[UIImagePickerController alloc] init];
        imagePicker.sourceType = UIImagePickerControllerSourceTypePhotoLibrary;
        imagePicker.delegate = self;
        [self presentViewController:imagePicker animated:YES completion:NULL];
        [imagePicker release];
    } else if ([TesterViewControllerUseCameraPlus isEqual:buttonTitle]) {
        /* Camera+ shoot and lightbox mode */
        [integrationManager openCameraPlusPickerWithMode:CameraPlusIntegrationModeShootAndLightbox];
    } else if ([TesterViewControllerEditPhoto isEqual:buttonTitle]) {
        /* Camera+ edit image mode */
        if (imageView.image) {
            [integrationManager openCameraPlusEditorWithImage:imageView.image];
        } else {
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"No image" 
                                                            message:@"Please choose an image first." 
                                                           delegate:self
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            [alert release];
        }
    } else if ([TesterViewControllerSharePhoto isEqual:buttonTitle]) {
        /* Camera+ share image mode */
        if (imageView.animationImages) {
            [integrationManager openCameraPlusSharingWithImages:imageView.animationImages];
        } else if (imageView.image) {
            [integrationManager openCameraPlusSharingWithImage:imageView.image];
        } else {
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"No image" 
                                                            message:@"Please choose an image first." 
                                                           delegate:self
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            [alert release];
        }
    } else if ([TesterViewControllerCreateWebLink isEqual:buttonTitle]) {
        /* Camera+ share image mode */
        if (imageView.animationImages) {
            [integrationManager createWebLinkWithImages:imageView.animationImages];
        } else if (imageView.image) {
            [integrationManager createWebLinkWithImage:imageView.image];
        } else {
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"No image" 
                                                            message:@"Please choose an image first." 
                                                           delegate:self
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            [alert release];
        }
    } else if ([TesterViewControllerRemovePhoto isEqual:buttonTitle]) {
        imageView.image = nil;
    }
}

#pragma mark - UIImagePickerControllerDelegate

/* Handle the standard UIImagePickerController responses for the Take Photo and Choose Existing functions. */

- (void)imagePickerController:(UIImagePickerController *)picker didFinishPickingMediaWithInfo:(NSDictionary *)info {
    UIImage *image = [info objectForKey:UIImagePickerControllerOriginalImage];
    if (image) {
        imageView.image = image;
    }
    
    [self dismissViewControllerAnimated:YES completion:NULL];
}

- (void)imagePickerControllerDidCancel:(UIImagePickerController *)picker {
    [self dismissViewControllerAnimated:YES completion:NULL];
}

#pragma mark - UIAlertViewDelegate

- (void)alertView:(UIAlertView *)alertView didDismissWithButtonIndex:(NSInteger)buttonIndex {
    NSString *buttonTitle = [alertView buttonTitleAtIndex:buttonIndex];
    
    if ([TesterViewControllerAppStore isEqualToString:buttonTitle] || [TesterViewControllerUpdate isEqualToString:buttonTitle]) {
        [[UIApplication sharedApplication] openURL:[NSURL URLWithString:@"itms-apps://itunes.apple.com/us/app/id329670577"]];
    }
}




#pragma mark - UIViewController

- (void)dealloc {
    [imageView release];
    [super dealloc];
}

- (void)viewDidUnload {
    [self setImageView:nil];
    [super viewDidUnload];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

@end
